@@ -1,8 +1,5 @@
 from __future__ import absolute_import
 
-from .logger import configure_logging
-configure_logging()
-
 from .trustar import TruStar
 from .models import *
 from .utils import *
